Index — Pootle 2.7.6 documentation

# Index

A | C | D | E | F | I | L | M | P | R | S | T | U | V | W

## A

add_vfolders django-admin command | AMAGAMA_URL setting

## C

calculate_checks django-admin command changed_languages django-admin command clear_stats django-admin command commit_to_vcs django-admin command | contributors django-admin command CONTRIBUTORS_EXCLUDED_NAMES setting CONTRIBUTORS_EXCLUDED_PROJECT_NAMES setting

## D

DESCRIPTION setting django-admin command add_vfolders calculate_checks changed_languages clear_stats commit_to_vcs contributors dump export find_duplicate_emails import init initdb last_change_id list_languages list_projects merge_user purge_user refresh_scores refresh_stats retry_failed_jobs revision run_cherrypy sync_stores test_checks update_from_vcs update_stores update_tmserver update_user_email verify_user webpack | dump django-admin command

## E

ENABLE_ALT_SRC setting environment variable POOTLE_SETTINGS, [1] PYTHONPATH | export django-admin command EXPORTED_DIRECTORY_MODE setting

## F

find_duplicate_emails django-admin command FUZZY_MATCH_MAX_LENGTH setting | FUZZY_MATCH_MIN_SIMILARITY setting

## I

import django-admin command init django-admin command | initdb django-admin command

## L

last_change_id django-admin command list_languages django-admin command | list_projects django-admin command

## M

MAX_AUTOTERMS setting merge_user django-admin command | MIN_AUTOTERMS setting

## P

PARSE_POOL_CULL_FREQUENCY setting PARSE_POOL_SIZE setting POOTLE_CACHE_TIMEOUT setting POOTLE_CAPTCHA_ENABLED setting POOTLE_CONTACT_EMAIL setting POOTLE_CONTACT_ENABLED setting POOTLE_CONTACT_REPORT_EMAIL setting POOTLE_CUSTOM_TEMPLATE_CONTEXT setting POOTLE_INSTANCE_ID setting POOTLE_LEGALPAGE_NOCHECK_PREFIXES setting POOTLE_LOG_DIRECTORY setting POOTLE_MARKUP_FILTER setting POOTLE_META_USERS setting POOTLE_MT_BACKENDS setting | POOTLE_QUALITY_CHECKER setting POOTLE_REPORTS_MARK_FUNC setting POOTLE_SETTINGS, [1] POOTLE_SIGNUP_ENABLED setting POOTLE_SYNC_FILE_MODE setting POOTLE_TITLE setting POOTLE_TM_SERVER setting POOTLE_TM_SERVER-INDEX_NAME setting POOTLE_TM_SERVER-WEIGHT setting POOTLE_TOP_STATS_CACHE_TIMEOUT setting POOTLE_TRANSLATION_DIRECTORY setting POOTLE_WORDCOUNT_FUNC setting purge_user django-admin command PYTHONPATH

## R

refresh_scores django-admin command refresh_stats django-admin command retry_failed_jobs django-admin command | revision django-admin command run_cherrypy django-admin command

## S

setting AMAGAMA_URL CONTRIBUTORS_EXCLUDED_NAMES CONTRIBUTORS_EXCLUDED_PROJECT_NAMES DESCRIPTION ENABLE_ALT_SRC EXPORTED_DIRECTORY_MODE FUZZY_MATCH_MAX_LENGTH FUZZY_MATCH_MIN_SIMILARITY MAX_AUTOTERMS MIN_AUTOTERMS PARSE_POOL_CULL_FREQUENCY PARSE_POOL_SIZE POOTLE_CACHE_TIMEOUT POOTLE_CAPTCHA_ENABLED POOTLE_CONTACT_EMAIL POOTLE_CONTACT_ENABLED POOTLE_CONTACT_REPORT_EMAIL POOTLE_CUSTOM_TEMPLATE_CONTEXT POOTLE_INSTANCE_ID POOTLE_LEGALPAGE_NOCHECK_PREFIXES POOTLE_LOG_DIRECTORY POOTLE_MARKUP_FILTER POOTLE_META_USERS POOTLE_MT_BACKENDS POOTLE_QUALITY_CHECKER POOTLE_REPORTS_MARK_FUNC POOTLE_SIGNUP_ENABLED POOTLE_SYNC_FILE_MODE POOTLE_TITLE POOTLE_TM_SERVER POOTLE_TM_SERVER-INDEX_NAME POOTLE_TM_SERVER-WEIGHT POOTLE_TOP_STATS_CACHE_TIMEOUT POOTLE_TRANSLATION_DIRECTORY POOTLE_WORDCOUNT_FUNC VCS_DIRECTORY | sync_stores django-admin command

## T

test_checks django-admin command

## U

update_from_vcs django-admin command update_stores django-admin command | update_tmserver django-admin command update_user_email django-admin command

## V

VCS_DIRECTORY setting | verify_user django-admin command

## W

webpack django-admin command